@@ -1,10 +1,10 @@
 /*
  *
- *  This file is part of MUMPS 5.6.1, released
- *  on Tue Jul 11 07:51:28 UTC 2023
+ *  This file is part of MUMPS 5.8.1, released
+ *  on Wed Jul 30 16:49:18 UTC 2025
  *
  *
- *  Copyright 1991-2023 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
+ *  Copyright 1991-2025 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
  *  Mumps Technologies, University of Bordeaux.
  *
  *  This version of MUMPS is provided to you free of charge. It is
@@ -76,6 +76,26 @@ MUMPS_ASSIGN_SYM_PERM(MUMPS_INT * f77sym_perm);
     F_SYMBOL(nullify_c_sym_perm,NULLIFY_C_SYM_PERM)
 void MUMPS_CALL
 MUMPS_NULLIFY_C_SYM_PERM();
+MUMPS_INT*
+mumps_get_glob2loc_rhs();
+#define MUMPS_ASSIGN_GLOB2LOC_RHS \
+    F_SYMBOL(assign_glob2loc_rhs,ASSIGN_GLOB2LOC_RHS)
+void MUMPS_CALL
+MUMPS_ASSIGN_GLOB2LOC_RHS(MUMPS_INT * f77glob2loc_rhs);
+#define MUMPS_NULLIFY_C_GLOB2LOC_RHS \
+    F_SYMBOL(nullify_c_glob2loc_rhs,NULLIFY_C_GLOB2LOC_RHS)
+void MUMPS_CALL
+MUMPS_NULLIFY_C_GLOB2LOC_RHS();
+MUMPS_INT*
+mumps_get_glob2loc_sol();
+#define MUMPS_ASSIGN_GLOB2LOC_SOL \
+    F_SYMBOL(assign_glob2loc_sol,ASSIGN_GLOB2LOC_SOL)
+void MUMPS_CALL
+MUMPS_ASSIGN_GLOB2LOC_SOL(MUMPS_INT * f77glob2loc_sol);
+#define MUMPS_NULLIFY_C_GLOB2LOC_SOL \
+    F_SYMBOL(nullify_c_glob2loc_sol,NULLIFY_C_GLOB2LOC_SOL)
+void MUMPS_CALL
+MUMPS_NULLIFY_C_GLOB2LOC_SOL();
 #define MUMPS_ICOPY_32TO64_64C_IP_C \
     F_SYMBOL(icopy_32to64_64c_ip_c,ICOPY_32TO64_64C_IP_C)
 void MUMPS_CALL
@@ -92,4 +112,12 @@ MUMPS_MALLOC_C(MUMPS_INT8 *address, MUMPS_INT8 *size);
     F_SYMBOL(free_c,FREE_C)
 void MUMPS_CALL
 MUMPS_FREE_C(void *address);
+#define MUMPS_RCOPY_32TO64_64C_IP_C \
+    F_SYMBOL(rcopy_32to64_64c_ip_c,RCOPY_32TO64_64C_IP_C)
+void MUMPS_CALL
+MUMPS_RCOPY_32TO64_64C_IP_C(float *inouttab, MUMPS_INT8 *sizetab);
+#define MUMPS_RCOPY_64TO32_64C_IP_C \
+    F_SYMBOL(rcopy_64to32_64c_ip_c,RCOPY_64TO32_64C_IP_C)
+void MUMPS_CALL
+MUMPS_RCOPY_64to32_64C_IP_C(double *inouttab, MUMPS_INT8 *sizetab);
 #endif /* MUMPS_COMMON_H */
